@@ -22,7 +22,7 @@ from s3prl.nn import S3PRLUpstream, Featurizer
 
 import s3prl_vc.models
 from s3prl_vc.datasets.datasets import AudioSCPMelDataset, AudioMelDataset
-from s3prl_vc.utils import read_hdf5
+from s3prl_vc.utils import read_hdf5, write_hdf5
 from s3prl_vc.utils.data import pad_list
 from s3prl_vc.utils.plot import plot_generated_and_ref_2d, plot_1d
 from s3prl_vc.vocoder import Vocoder
@@ -204,6 +204,17 @@ def main():
                 origin="lower",
             )
 
+            # write feats
+            if not os.path.exists(os.path.join(config["outdir"], "feats")):
+                os.makedirs(os.path.join(config["outdir"], "feats"), exist_ok=True)
+
+            write_hdf5(
+                config["outdir"] + f"/feats/{utt_id}.h5",
+                "feats",
+                out.cpu().numpy().astype(np.float32),
+            )
+
+            # write waveform
             if not os.path.exists(os.path.join(config["outdir"], "wav")):
                 os.makedirs(os.path.join(config["outdir"], "wav"), exist_ok=True)
 
